@@ -897,7 +897,7 @@ static void tcc_cleanup(void)
     macro_ptr = NULL;
 }
 
-LIBTCCAPI TCCState *tcc_new(void)
+LIBTCCAPI TCCState *tcc_new(const char *init_lib_path)
 {
     TCCState *s;
     char buffer[100];
@@ -909,11 +909,15 @@ LIBTCCAPI TCCState *tcc_new(void)
     if (!s)
         return NULL;
     tcc_state = s;
+    if (init_lib_path == NULL) {
 #ifdef _WIN32
-    tcc_set_lib_path_w32(s);
+        tcc_set_lib_path_w32(s);
 #else
-    tcc_set_lib_path(s, CONFIG_TCCDIR);
+        tcc_set_lib_path(s, CONFIG_TCCDIR);
 #endif
+    } else {
+        tcc_set_lib_path(s, init_lib_path);
+    }
     s->output_type = TCC_OUTPUT_MEMORY;
     preprocess_new();
     s->include_stack_ptr = s->include_stack;
